Accrued benefit under a career-average-earnings plan
AB_cae.RdComputes the accrued benefit using salary history through the valuation date.
Examples
AB_cae(
salary_history = c(100000, 104000, 108160),
p = 1
)
#> [1] 3121.6
AB_cae.RdComputes the accrued benefit using salary history through the valuation date.
AB_cae(
salary_history = c(100000, 104000, 108160),
p = 1
)
#> [1] 3121.6