Cost of insurance for Type B universal life
coi_ul_typeB.RdComputes the one-period cost of insurance for a Type B universal life contract: $$ \mathrm{COI}_t = \frac{B_t q_{x+t-1}}{1+i_t^q}. $$
coi_ul_typeB.RdComputes the one-period cost of insurance for a Type B universal life contract: $$ \mathrm{COI}_t = \frac{B_t q_{x+t-1}}{1+i_t^q}. $$