Point-to-point index growth rates
iP_eiul.RdComputes annual point-to-point index growth rates from successive index values, matching Equation (16.12).
Examples
iP_eiul(c(1000, 1050, 1200, 1100))
#> [1] 0.05000000 0.14285714 -0.08333333
iP_eiul.RdComputes annual point-to-point index growth rates from successive index values, matching Equation (16.12).
iP_eiul(c(1000, 1050, 1200, 1100))
#> [1] 0.05000000 0.14285714 -0.08333333