Solve the yield rate by the equation of value
solve_yield.RdFinds the interest rate i such that the present value of the cash flows is 0.
Usage
solve_yield(cf, t, interval = c(-0.99, 1), tol = 1e-10)solve_yield.RdFinds the interest rate i such that the present value of the cash flows is 0.
solve_yield(cf, t, interval = c(-0.99, 1), tol = 1e-10)