Accrued benefit for a career average earnings plan
AB_cae.RdComputes the accrued benefit using actual salary history only.
Examples
AB_cae(salary_history = c(100000, 104000, 108160), p = 1)
#> [1] 3121.6
AB_cae.RdComputes the accrued benefit using actual salary history only.
AB_cae(salary_history = c(100000, 104000, 108160), p = 1)
#> [1] 3121.6