Accrued benefit under a final-average-salary plan
AB_fas.RdComputes the accrued benefit using salary and service history through the valuation date.
Examples
AB_fas(
salary_history = c(150000, 156000),
p = 1,
fas_years = 2
)
#> [1] 3060
AB_fas.RdComputes the accrued benefit using salary and service history through the valuation date.
AB_fas(
salary_history = c(150000, 156000),
p = 1,
fas_years = 2
)
#> [1] 3060