Accrued benefit for a final average salary plan
AB_fas.RdComputes the accrued benefit at the current date using service and salary history only.
Examples
AB_fas(salary_history = c(150000, 156000), p = 1, fas_years = 2)
#> [1] 3060
AB_fas.RdComputes the accrued benefit at the current date using service and salary history only.
AB_fas(salary_history = c(150000, 156000), p = 1, fas_years = 2)
#> [1] 3060