Continuous multiple-decrement insurance APV \(\overline{A}_{x}^{(j)}\)
Abarxj_md.RdComputes the actuarial present value of a benefit payable at the moment of decrement by Cause \(j\), matching Equation (14.4) in Chapter 14.
Abarxj_md.RdComputes the actuarial present value of a benefit payable at the moment of decrement by Cause \(j\), matching Equation (14.4) in Chapter 14.