Discrete multiple-decrement insurance APV \(A_{x}^{(j)}\)
Axj_md.RdComputes the actuarial present value of a benefit payable at the end of the year of decrement if decrement occurs by Cause \(j\), matching Equation (14.3b) in Chapter 14.
Details
The function evaluates $$ A_{x}^{(j)} = \sum_{k=0}^{n-1} v^{k+1} {}_{k}p_{x}^{(\tau)} q_{x+k}^{(j)} $$ with an optional benefit amount multiplier.
Examples
q1 <- c(.02, .02, .02, .02, .02)
q2 <- c(.03, .04, .05, .06, .00)
q3 <- c(.00, .00, .00, .00, .98)
qtau <- q1 + q2 + q3
ptau <- numeric(length(qtau))
ptau[1] <- 1
for (k in 2:length(qtau)) {
ptau[k] <- prod(1 - qtau[1:(k - 1)])
}
Axj_md(qj = q1, ptau = ptau, i = 0.06, benefit = 1000)
#> [1] 75.34884