Multi-life survival and failure probabilities
multilife_survival_probabilities.RdComputes joint-life and last-survivor survival and failure probabilities for two independent lives.
Usage
tpxy(x, y, t, tbl = NULL, model = NULL, ...)
tqxy(x, y, t, tbl = NULL, model = NULL, ...)
tpxybar(x, y, t, tbl = NULL, model = NULL, ...)
tqxybar(x, y, t, tbl = NULL, model = NULL, ...)Details
tpxy() computes the joint-life survival probability
$$
{}_tp_{xy}
=
{}_tp_x\,{}_tp_y.
$$
tqxy() computes the joint-life failure probability
$$
{}_tq_{xy}
=
1-{}_tp_{xy}.
$$
tpxybar() computes the last-survivor survival probability
$$
{}_tp_{\overline{xy}}
=
{}_tp_x + {}_tp_y - {}_tp_x\,{}_tp_y.
$$
tqxybar() computes the last-survivor failure probability
$$
{}_tq_{\overline{xy}}
=
1-{}_tp_{\overline{xy}}.
$$
All calculations assume the future lifetimes are independent.
Joint-life probabilities require both lives to satisfy the survival condition, whereas last-survivor probabilities require at least one life to survive.
Examples
tpxy(
40, 50,
t = 10,
model = "uniform",
omega = 100
)
#> [1] 0.6666667
tqxy(
40, 50,
t = 10,
model = "uniform",
omega = 100
)
#> [1] 0.3333333
tpxybar(
40, 50,
t = 10,
model = "uniform",
omega = 100
)
#> [1] 0.9666667
tqxybar(
40, 50,
t = 10,
model = "uniform",
omega = 100
)
#> [1] 0.03333333