Present value of cash flows using spot rates
pv_spot_cashflows.RdDiscounts deterministic cash flows using spot rates matched to their maturities.
Usage
pv_spot_cashflows(
amounts,
times,
spot,
compounding = c("annual", "semiannual")
)pv_spot_cashflows.RdDiscounts deterministic cash flows using spot rates matched to their maturities.
pv_spot_cashflows(
amounts,
times,
spot,
compounding = c("annual", "semiannual")
)