Actuarial present values under spot rates
spot_interest_apvs.RdComputes life-contingent actuarial present values using annual effective spot rates by maturity.
Usage
nEx_spot(qx, z, benefit = 1)
Axn1_spot(qx, z, benefit = 1)
Axn_spot(qx, z, benefit = 1)
axn_spot(qx, z, type = c("immediate", "due"), benefit = 1)Details
If \(z_t\) denotes the annual effective spot rate for maturity \(t\), the corresponding discount factor is $$(1+z_t)^{-t}.$$
nEx_spot() computes a pure endowment.
Axn1_spot() computes term insurance payable at the end of the year
of death.
Axn_spot() computes endowment insurance.
axn_spot() computes a temporary annuity-immediate or
annuity-due.
Each payment is discounted using the spot rate corresponding to its maturity rather than a single level interest rate.
The pure endowment is $$ {}_nE = {}_np_x(1+z_n)^{-n}. $$
Term insurance is obtained by discounting each death benefit using the spot rate corresponding to its payment year.
Endowment insurance equals the sum of the corresponding term insurance and pure endowment.
Temporary annuities discount each payment using the spot rate for its payment time.